"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SMTStore = void 0;
const lisk_utils_1 = require("@liskhq/lisk-utils");
const db_keys_1 = require("../db_keys");
class SMTStore {
    constructor(db, data) {
        this._db = db;
        this._data = data !== null && data !== void 0 ? data : new lisk_utils_1.dataStructures.BufferMap();
    }
    async get(key) {
        const prefixedKey = this._getKey(key);
        const cachedValue = this._data.get(prefixedKey);
        if (cachedValue) {
            return cachedValue;
        }
        const storedValue = await this._db.get(prefixedKey);
        this._data.set(prefixedKey, storedValue);
        return storedValue;
    }
    async set(key, value) {
        const prefixedKey = this._getKey(key);
        this._data.set(prefixedKey, value);
    }
    async del(key) {
        const prefixedKey = this._getKey(key);
        this._data.delete(prefixedKey);
    }
    finalize(batch) {
        for (const [key, value] of this._data.entries()) {
            batch.set(key, value);
        }
    }
    _getKey(key) {
        return Buffer.concat([db_keys_1.DB_KEY_STATE_SMT, key]);
    }
}
exports.SMTStore = SMTStore;
//# sourceMappingURL=smt_store.js.map