"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getActiveValidatorsUpdate = exports.calculateActiveValidatorsUpdate = void 0;
const lisk_sdk_1 = require("lisk-sdk");
const calculateActiveValidatorsUpdate = (certificate, validatorsHashPreimage, lastCertificate) => {
    let certificateThreshold;
    const validatorDataAtCertificate = validatorsHashPreimage.find(validatorsData => validatorsData.validatorsHash.equals(certificate.validatorsHash));
    if (!validatorDataAtCertificate) {
        throw new Error('No validators data found for the certificate height.');
    }
    const validatorDataAtLastCertificate = validatorsHashPreimage.find(validatorsData => validatorsData.validatorsHash.equals(lastCertificate.validatorsHash));
    if (!validatorDataAtLastCertificate) {
        throw new Error('No validators data found for the given last certificate height.');
    }
    if (validatorDataAtCertificate.certificateThreshold ===
        validatorDataAtLastCertificate.certificateThreshold) {
        certificateThreshold = validatorDataAtLastCertificate.certificateThreshold;
    }
    else {
        certificateThreshold = validatorDataAtCertificate.certificateThreshold;
    }
    const activeValidatorsUpdate = (0, exports.getActiveValidatorsUpdate)(validatorDataAtLastCertificate.validators, validatorDataAtCertificate.validators);
    return { activeValidatorsUpdate, certificateThreshold };
};
exports.calculateActiveValidatorsUpdate = calculateActiveValidatorsUpdate;
const getActiveValidatorsUpdate = (currentValidators, newValidators) => {
    const currentValidatorsMap = new lisk_sdk_1.utils.dataStructures.BufferMap();
    const allBLSKeysSet = new lisk_sdk_1.utils.dataStructures.BufferSet();
    for (const v of currentValidators) {
        currentValidatorsMap.set(v.blsKey, v);
        allBLSKeysSet.add(v.blsKey);
    }
    const validatorsUpdate = [];
    const blsKeysUpdate = [];
    const newBLSKeys = new lisk_sdk_1.utils.dataStructures.BufferSet();
    for (const v of newValidators) {
        newBLSKeys.add(v.blsKey);
        allBLSKeysSet.add(v.blsKey);
        const currentValidator = currentValidatorsMap.get(v.blsKey);
        if (!currentValidator) {
            blsKeysUpdate.push(v.blsKey);
            validatorsUpdate.push(v);
            continue;
        }
        if (currentValidator.bftWeight !== v.bftWeight) {
            validatorsUpdate.push(v);
        }
    }
    for (const v of currentValidators) {
        if (!newBLSKeys.has(v.blsKey)) {
            validatorsUpdate.push({
                blsKey: v.blsKey,
                bftWeight: BigInt(0),
            });
        }
    }
    blsKeysUpdate.sort((a, b) => a.compare(b));
    validatorsUpdate.sort((a, b) => a.blsKey.compare(b.blsKey));
    const bftWeightsUpdate = validatorsUpdate.map(v => v.bftWeight);
    const allBLSKeys = [...allBLSKeysSet];
    allBLSKeys.sort((a, b) => a.compare(b));
    let bitmap = BigInt(0);
    const bitmapSize = Number(BigInt(allBLSKeys.length + 7) / BigInt(8));
    for (const validator of validatorsUpdate) {
        const index = allBLSKeys.findIndex(k => k.equals(validator.blsKey));
        bitmap |= BigInt(1) << BigInt(index);
    }
    const hexBitmap = bitmap.toString(16);
    let bftWeightsUpdateBitmap = Buffer.from(hexBitmap.length % 2 === 0 ? hexBitmap : `0${hexBitmap}`, 'hex');
    if (bftWeightsUpdateBitmap.length < bitmapSize) {
        bftWeightsUpdateBitmap = Buffer.concat([
            Buffer.alloc(bitmapSize - bftWeightsUpdateBitmap.length),
            bftWeightsUpdateBitmap,
        ]);
    }
    return {
        blsKeysUpdate,
        bftWeightsUpdate,
        bftWeightsUpdateBitmap,
    };
};
exports.getActiveValidatorsUpdate = getActiveValidatorsUpdate;
//# sourceMappingURL=active_validators_update.js.map