"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNextCertificateFromAggregateCommits = exports.checkChainOfTrust = exports.getCertificateFromAggregateCommit = void 0;
const lisk_sdk_1 = require("lisk-sdk");
const getCertificateFromAggregateCommit = (aggregateCommit, blockHeaders) => {
    const blockHeader = blockHeaders.find(header => header.height === aggregateCommit.height);
    if (!blockHeader) {
        throw new Error('No block header found for the given aggregate height.');
    }
    return {
        ...(0, lisk_sdk_1.computeUnsignedCertificateFromBlockHeader)(new lisk_sdk_1.chain.BlockHeader(blockHeader)),
        aggregationBits: aggregateCommit.aggregationBits,
        signature: aggregateCommit.certificateSignature,
    };
};
exports.getCertificateFromAggregateCommit = getCertificateFromAggregateCommit;
const checkChainOfTrust = (lastValidatorsHash, blsKeyToBFTWeight, lastCertificateThreshold, aggregateCommit, blockHeaders, validatorsHashPreimage) => {
    const blockHeader = blockHeaders.find(header => header.height === aggregateCommit.height - 1);
    if (!blockHeader) {
        throw new Error('No block header found for the given aggregate height.');
    }
    if (lastValidatorsHash.equals(blockHeader.validatorsHash)) {
        return true;
    }
    let aggregateBFTWeight = BigInt(0);
    const validatorData = validatorsHashPreimage.find(data => data.validatorsHash.equals(blockHeader.validatorsHash));
    if (!validatorData) {
        throw new Error('No validators data found for the given validatorsHash.');
    }
    for (let i = 0; i < validatorData.validators.length; i += 1) {
        if (aggregateCommit.aggregationBits.toString('hex')[i] === '1') {
            const blsKey = validatorData.validators[i].blsKey.toString('hex');
            if (!blsKeyToBFTWeight[blsKey]) {
                return false;
            }
            aggregateBFTWeight += blsKeyToBFTWeight[blsKey];
        }
    }
    return aggregateBFTWeight >= lastCertificateThreshold;
};
exports.checkChainOfTrust = checkChainOfTrust;
const getNextCertificateFromAggregateCommits = (blockHeaders, aggregateCommits, validatorsHashPreimage, bftHeights, lastCertificate) => {
    const blockHeaderAtLastCertifiedHeight = blockHeaders.find(header => header.height === lastCertificate.height);
    if (!blockHeaderAtLastCertifiedHeight) {
        throw new Error('No block header found for the last certified height.');
    }
    const validatorDataAtLastCertifiedHeight = validatorsHashPreimage.find(data => data.validatorsHash.equals(blockHeaderAtLastCertifiedHeight === null || blockHeaderAtLastCertifiedHeight === void 0 ? void 0 : blockHeaderAtLastCertifiedHeight.validatorsHash));
    if (!validatorDataAtLastCertifiedHeight) {
        throw new Error('No validatorsHash preimage data present for the given validatorsHash.');
    }
    const blsKeyToBFTWeight = {};
    for (const validator of validatorDataAtLastCertifiedHeight.validators) {
        blsKeyToBFTWeight[validator.blsKey.toString('hex')] = validator.bftWeight;
    }
    let height = bftHeights.maxHeightCertified;
    while (height > lastCertificate.height) {
        const aggregateCommitAtHeight = aggregateCommits.find(a => a.height === height);
        if (aggregateCommitAtHeight !== undefined) {
            const valid = (0, exports.checkChainOfTrust)(blockHeaderAtLastCertifiedHeight.validatorsHash, blsKeyToBFTWeight, validatorDataAtLastCertifiedHeight.certificateThreshold, aggregateCommitAtHeight, blockHeaders, validatorsHashPreimage);
            if (valid) {
                return (0, exports.getCertificateFromAggregateCommit)(aggregateCommitAtHeight, blockHeaders);
            }
        }
        height -= 1;
    }
    return undefined;
};
exports.getNextCertificateFromAggregateCommits = getNextCertificateFromAggregateCommits;
//# sourceMappingURL=certificate_generation.js.map