import { BasePlugin, PluginInitContext } from 'lisk-sdk';
import { Endpoint } from './endpoint';
import { ChainConnectorPluginConfig } from './types';
export declare class ChainConnectorPlugin extends BasePlugin<ChainConnectorPluginConfig> {
    endpoint: Endpoint;
    configSchema: {
        $id: string;
        type: string;
        properties: {
            receivingChainIPCPath: {
                type: string;
                description: string;
            };
            receivingChainWsURL: {
                type: string;
                description: string;
            };
            ccuFrequency: {
                type: string;
                description: string;
            };
            encryptedPrivateKey: {
                type: string;
                description: string;
            };
            ccuFee: {
                type: string;
                format: string;
                description: string;
            };
            isSaveCCU: {
                type: string;
                description: string;
            };
            maxCCUSize: {
                type: string;
                description: string;
                minimum: number;
                maximum: number;
            };
            ccuSaveLimit: {
                type: string;
                description: string;
                minimum: number;
            };
            registrationHeight: {
                type: string;
                description: string;
                minimum: number;
            };
            receivingChainID: {
                type: string;
                description: string;
            };
        };
        required: string[];
        default: {
            ccuFrequency: number;
            isSaveCCU: boolean;
            maxCCUSize: number;
            registrationHeight: number;
            ccuSaveLimit: number;
        };
    };
    private _chainConnectorPluginDB;
    private _chainConnectorStore;
    private _lastCertificate;
    private _ccuFrequency;
    private _maxCCUSize;
    private _isSaveCCU;
    private _receivingChainClient;
    private _sendingChainClient;
    private _ownChainID;
    private _receivingChainID;
    private _isReceivingChainMainchain;
    private _registrationHeight;
    private _ccuSaveLimit;
    private _receivingChainFinalizedHeight;
    private _heightToDeleteIndex;
    get nodeModulePath(): string;
    init(context: PluginInitContext): Promise<void>;
    load(): Promise<void>;
    unload(): Promise<void>;
    private _newBlockReceivingChainHandler;
    private _newBlockHandler;
    private _computeCCUParams;
    private _findNextCertificate;
    private _saveDataOnNewBlock;
    private _deleteBlockHandler;
    private _cleanup;
    private _submitCCU;
    private _initializeReceivingChainClient;
}
