"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculateMessageWitnesses = void 0;
const lisk_sdk_1 = require("lisk-sdk");
const calculateMessageWitnesses = (inboxSizeOnReceivingChain, outboxSizeOnSendingChain, lastSentCCM, ccmsToBeIncluded, maxCCUSize) => {
    const allSerializedCCMs = [];
    const includedSerializedCCMs = [];
    let lastCCMWithHeight;
    let totalSize = 0;
    for (const ccmsFromEvents of ccmsToBeIncluded) {
        const { ccms, height } = ccmsFromEvents;
        for (const ccm of ccms) {
            if (height !== 0 && lastSentCCM.height === height) {
                if (ccm.nonce === lastSentCCM.nonce) {
                    continue;
                }
            }
            if (inboxSizeOnReceivingChain < outboxSizeOnSendingChain) {
                const ccmBytes = lisk_sdk_1.codec.encode(lisk_sdk_1.ccmSchema, ccm);
                totalSize += ccmBytes.length;
                if (totalSize < maxCCUSize) {
                    includedSerializedCCMs.push(ccmBytes);
                    lastCCMWithHeight = { ...ccm, height: ccmsFromEvents.height };
                }
                allSerializedCCMs.push(ccmBytes);
            }
        }
    }
    if (includedSerializedCCMs.length < 1) {
        return {
            crossChainMessages: [],
            messageWitnessHashes: [],
            lastCCMToBeSent: undefined,
        };
    }
    if (includedSerializedCCMs.length === allSerializedCCMs.length) {
        return {
            crossChainMessages: includedSerializedCCMs,
            messageWitnessHashes: [],
            lastCCMToBeSent: lastCCMWithHeight,
        };
    }
    const remainingSerializedCCMs = allSerializedCCMs.slice(includedSerializedCCMs.length);
    const messageWitnessHashes = lisk_sdk_1.tree.regularMerkleTree.calculateRightWitness(inboxSizeOnReceivingChain + includedSerializedCCMs.length, remainingSerializedCCMs);
    return {
        crossChainMessages: includedSerializedCCMs,
        messageWitnessHashes,
        lastCCMToBeSent: lastCCMWithHeight,
    };
};
exports.calculateMessageWitnesses = calculateMessageWitnesses;
//# sourceMappingURL=inbox_update.js.map