"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.authorizeRequestSchema = exports.ccmsFromEventsSchema = exports.listOfCCUsSchema = exports.lastSentCCMWithHeight = exports.validatorsHashPreimageInfoSchema = exports.aggregateCommitsInfoSchema = exports.blockHeadersInfoSchema = exports.validatorsDataSchema = exports.configSchema = void 0;
const lisk_sdk_1 = require("lisk-sdk");
const constants_1 = require("./constants");
const pluginSchemaIDPrefix = '/lisk/plugins/chainConnector';
exports.configSchema = {
    $id: `${pluginSchemaIDPrefix}/config`,
    type: 'object',
    properties: {
        receivingChainIPCPath: {
            type: 'string',
            description: 'The IPC path of a receiving node',
        },
        receivingChainWsURL: {
            type: 'string',
            description: 'The WS url of a receiving node',
        },
        ccuFrequency: {
            type: 'integer',
            description: 'Number of blocks after which a CCU should be created',
        },
        encryptedPrivateKey: {
            type: 'string',
            description: 'Encrypted privateKey of the relayer',
        },
        ccuFee: {
            type: 'string',
            format: 'uint64',
            description: 'Fee to be paid for each CCU transaction',
        },
        isSaveCCU: {
            type: 'boolean',
            description: 'Flag for the user to either save or send a CCU on creation. Send is by default.',
        },
        maxCCUSize: {
            type: 'integer',
            description: 'Maximum size of CCU to be allowed',
            minimum: 1,
            maximum: constants_1.CCU_TOTAL_CCM_SIZE,
        },
        ccuSaveLimit: {
            type: 'integer',
            description: 'Number of CCUs to save.',
            minimum: -1,
        },
        registrationHeight: {
            type: 'integer',
            description: 'Height at the time of registration on the receiving chain.',
            minimum: 1,
        },
        receivingChainID: {
            type: 'string',
            description: 'Chain ID of the receiving chain.',
        },
    },
    required: ['ccuFee', 'encryptedPrivateKey', 'receivingChainID'],
    default: {
        ccuFrequency: constants_1.CCU_FREQUENCY,
        isSaveCCU: false,
        maxCCUSize: constants_1.CCU_TOTAL_CCM_SIZE,
        registrationHeight: constants_1.DEFAULT_REGISTRATION_HEIGHT,
        ccuSaveLimit: constants_1.DEFAULT_CCU_SAVE_LIMIT,
    },
};
exports.validatorsDataSchema = {
    $id: `${pluginSchemaIDPrefix}/validatorsData`,
    type: 'object',
    required: ['validators', 'certificateThreshold', 'validatorsHash'],
    properties: {
        validators: {
            type: 'array',
            fieldNumber: 1,
            items: {
                type: 'object',
                required: ['address', 'blsKey', 'bftWeight'],
                properties: {
                    address: { dataType: 'bytes', fieldNumber: 1 },
                    blsKey: { dataType: 'bytes', fieldNumber: 2 },
                    bftWeight: { dataType: 'uint64', fieldNumber: 3 },
                },
            },
        },
        certificateThreshold: { dataType: 'uint64', fieldNumber: 2 },
        validatorsHash: { dataType: 'bytes', fieldNumber: 3 },
    },
};
exports.blockHeadersInfoSchema = {
    $id: `${pluginSchemaIDPrefix}/blockHeaders`,
    type: 'object',
    properties: {
        blockHeaders: {
            type: 'array',
            fieldNumber: 1,
            items: {
                ...lisk_sdk_1.chain.blockHeaderSchema,
            },
        },
    },
};
exports.aggregateCommitsInfoSchema = {
    $id: `${pluginSchemaIDPrefix}/aggregateCommits`,
    type: 'object',
    properties: {
        aggregateCommits: {
            type: 'array',
            fieldNumber: 1,
            items: {
                ...lisk_sdk_1.aggregateCommitSchema,
            },
        },
    },
};
exports.validatorsHashPreimageInfoSchema = {
    $id: `${pluginSchemaIDPrefix}/validatorsHashPreimage`,
    type: 'object',
    properties: {
        validatorsHashPreimage: {
            type: 'array',
            fieldNumber: 1,
            items: {
                ...exports.validatorsDataSchema,
            },
        },
    },
};
exports.lastSentCCMWithHeight = {
    $id: `${pluginSchemaIDPrefix}/lastSentCCMWithHeight`,
    type: 'object',
    required: [...lisk_sdk_1.ccmSchema.required, 'height'],
    properties: {
        ...lisk_sdk_1.ccmSchema.properties,
        height: { dataType: 'uint32', fieldNumber: Object.keys(lisk_sdk_1.ccmSchema.properties).length + 1 },
    },
};
exports.listOfCCUsSchema = {
    $id: `${pluginSchemaIDPrefix}/listOfCCUs`,
    type: 'object',
    properties: {
        listOfCCUs: {
            type: 'array',
            fieldNumber: 1,
            items: {
                ...lisk_sdk_1.chain.transactionSchema,
            },
        },
    },
};
exports.ccmsFromEventsSchema = {
    $id: `${pluginSchemaIDPrefix}/ccmsFromEvents`,
    type: 'object',
    properties: {
        ccmsFromEvents: {
            type: 'array',
            fieldNumber: 1,
            items: {
                type: 'object',
                required: ['ccms', 'height', 'inclusionProof', 'outboxSize'],
                properties: {
                    ccms: {
                        type: 'array',
                        fieldNumber: 1,
                        items: {
                            ...lisk_sdk_1.ccmSchema,
                        },
                    },
                    height: { dataType: 'uint32', fieldNumber: 2 },
                    inclusionProof: {
                        type: 'object',
                        fieldNumber: 3,
                        required: ['siblingHashes', 'bitmap'],
                        properties: {
                            siblingHashes: {
                                type: 'array',
                                fieldNumber: 1,
                                items: {
                                    dataType: 'bytes',
                                },
                            },
                            bitmap: {
                                dataType: 'bytes',
                                fieldNumber: 2,
                            },
                        },
                    },
                    outboxSize: {
                        dataType: 'uint32',
                        fieldNumber: 4,
                    },
                },
            },
        },
    },
};
exports.authorizeRequestSchema = {
    $id: '/lisk/chainConnector/authorizeRequest',
    type: 'object',
    required: ['password', 'enable'],
    properties: {
        password: {
            type: 'string',
        },
        enable: {
            type: 'boolean',
        },
    },
};
//# sourceMappingURL=schemas.js.map