import { BasePlugin, PluginInitContext } from 'lisk-sdk';
import { MonitorPluginConfig, SharedState } from './types';
import { Endpoint } from './endpoint';
export declare class MonitorPlugin extends BasePlugin<MonitorPluginConfig> {
    configSchema: {
        $id: string;
        type: string;
        properties: {
            port: {
                type: string;
                minimum: number;
                maximum: number;
            };
            host: {
                type: string;
                format: string;
            };
            whiteList: {
                type: string;
                items: {
                    type: string;
                };
            };
            cors: {
                type: string;
                properties: {
                    origin: {
                        anyOf: {
                            type: string;
                        }[];
                    };
                    methods: {
                        type: string;
                    };
                };
                required: string[];
            };
            limits: {
                type: string;
                properties: {
                    max: {
                        type: string;
                    };
                    delayMs: {
                        type: string;
                    };
                    delayAfter: {
                        type: string;
                    };
                    windowMs: {
                        type: string;
                    };
                    headersTimeout: {
                        type: string;
                        minimum: number;
                        maximum: number;
                    };
                    serverSetTimeout: {
                        type: string;
                        minimum: number;
                        maximum: number;
                    };
                };
                required: string[];
            };
        };
        required: string[];
        default: {
            port: number;
            host: string;
            whiteList: string[];
            cors: {
                origin: string;
                methods: string[];
            };
            limits: {
                max: number;
                delayMs: number;
                delayAfter: number;
                windowMs: number;
                headersTimeout: number;
                serverSetTimeout: number;
            };
        };
    };
    endpoint: Endpoint;
    private _server;
    private _app;
    private _state;
    get nodeModulePath(): string;
    init(context: PluginInitContext): Promise<void>;
    load(): Promise<void>;
    unload(): Promise<void>;
    get state(): SharedState;
    private _registerMiddlewares;
    private _registerAfterMiddlewares;
    private _registerControllers;
    private _subscribeToEvents;
    private _handlePostTransactionAnnounce;
    private _cleanUpTransactionStats;
    private _handleFork;
    private _handlePostBlock;
}
