"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExportCommand = void 0;
const fs = require("fs-extra");
const path = require("path");
const flags_1 = require("../../../utils/flags");
const base_ipc_client_1 = require("../base_ipc_client");
const constants_1 = require("../../../constants");
class ExportCommand extends base_ipc_client_1.BaseIPCClientCommand {
    async run() {
        const { flags } = await this.parse(ExportCommand);
        if (!this._client) {
            this.error('APIClient is not initialized.');
        }
        const { dir } = path.parse(flags.output);
        fs.ensureDirSync(dir);
        const response = await this._client.invoke('generator_getAllKeys');
        const keys = response.keys.map(k => {
            if (k.type === 'encrypted') {
                return {
                    address: k.address,
                    encrypted: k.data,
                };
            }
            return {
                address: k.address,
                plain: k.data,
            };
        });
        fs.writeJSONSync(flags.output, { keys }, { spaces: ' ', mode: constants_1.OWNER_READ_WRITE });
    }
}
ExportCommand.description = 'Export to <FILE>.';
ExportCommand.examples = [
    'keys:export --output /mypath/keys.json',
    'keys:export --output /mypath/keys.json --data-path ./data ',
];
ExportCommand.flags = {
    ...base_ipc_client_1.BaseIPCClientCommand.flags,
    output: {
        ...flags_1.flagsWithParser.output,
        required: true,
    },
};
exports.ExportCommand = ExportCommand;
//# sourceMappingURL=export.js.map