"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateCommand = void 0;
const lisk_passphrase_1 = require("@liskhq/lisk-passphrase");
const core_1 = require("@oclif/core");
const fs = require("fs-extra");
const path = require("path");
const flags_1 = require("../../../utils/flags");
const constants_1 = require("../../../constants");
class CreateCommand extends core_1.Command {
    async run() {
        const { flags: { output }, } = await this.parse(CreateCommand);
        if (output) {
            const { dir } = path.parse(output);
            fs.ensureDirSync(dir);
        }
        const passphrase = lisk_passphrase_1.Mnemonic.generateMnemonic(256);
        if (output) {
            fs.writeJSONSync(output, { passphrase }, { spaces: ' ', mode: constants_1.OWNER_READ_WRITE });
        }
        else {
            this.log(JSON.stringify({ passphrase }, undefined, '  '));
        }
    }
}
CreateCommand.description = 'Returns a randomly generated 24 words mnemonic passphrase.';
CreateCommand.examples = ['passphrase:create', 'passphrase:create --output /mypath/passphrase.json'];
CreateCommand.flags = {
    output: flags_1.flagsWithParser.output,
};
exports.CreateCommand = CreateCommand;
//# sourceMappingURL=create.js.map