"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_bootstrap_command_1 = require("../../base_bootstrap_command");
class CommandCommand extends base_bootstrap_command_1.default {
    async run() {
        const { args } = await this.parse(CommandCommand);
        const { moduleName, commandName } = args;
        const regexWhitespace = /\s/g;
        const regexCamelCase = /[a-z]+((\d)|([A-Z0-9][a-z0-9]+))*([A-Z])?/;
        const regexAlphabets = /[^A-Za-z]/;
        if (!regexCamelCase.test(moduleName) ||
            regexWhitespace.test(moduleName) ||
            regexAlphabets.test(moduleName)) {
            this.error('Invalid module name');
        }
        if (!regexCamelCase.test(commandName) ||
            regexWhitespace.test(commandName) ||
            regexAlphabets.test(commandName)) {
            this.error('Invalid command name');
        }
        if (!this._isLiskAppDir(process.cwd())) {
            this.error('You can run this command only in lisk app directory. Run "lisk init --help" command for more details.');
        }
        this.log(`Creating command skeleton with command name "${commandName}" for module "${moduleName}"`);
        return this._runBootstrapCommand('lisk:generate:command', {
            moduleName,
            commandName,
        });
    }
}
CommandCommand.description = 'Creates an command skeleton for the given module name, name and id.';
CommandCommand.examples = [
    'generate:command moduleName commandName commandID',
    'generate:command nft transfer 1',
];
CommandCommand.args = [
    {
        name: 'moduleName',
        description: 'Module name.',
        required: true,
    },
    {
        name: 'commandName',
        description: 'Asset name.',
        required: true,
    },
];
exports.default = CommandCommand;
//# sourceMappingURL=command.js.map