"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SubmitSidechainCrossChainUpdateCommand = void 0;
const state_machine_1 = require("../../../../state_machine");
const base_cross_chain_update_command_1 = require("../../base_cross_chain_update_command");
const constants_1 = require("../../constants");
const utils_1 = require("../../utils");
class SubmitSidechainCrossChainUpdateCommand extends base_cross_chain_update_command_1.BaseCrossChainUpdateCommand {
    async verify(context) {
        await this.verifyCommon(context, false);
        return {
            status: state_machine_1.VerifyStatus.OK,
        };
    }
    async execute(context) {
        const [decodedCCMs, ok] = await this.executeCommon(context, false);
        if (!ok) {
            return;
        }
        const { params } = context;
        try {
            context.contextStore.set(constants_1.CONTEXT_STORE_KEY_CCM_PROCESSING, true);
            for (let i = 0; i < decodedCCMs.length; i += 1) {
                const ccm = decodedCCMs[i];
                const ccmBytes = params.inboxUpdate.crossChainMessages[i];
                const ccmID = (0, utils_1.getIDFromCCMBytes)(ccmBytes);
                const ccmContext = {
                    ...context,
                    ccm,
                    eventQueue: context.eventQueue.getChildQueue(ccmID),
                };
                await this.apply(ccmContext);
                await this.internalMethod.appendToInboxTree(context, params.sendingChainID, ccmBytes);
            }
        }
        finally {
            context.contextStore.delete(constants_1.CONTEXT_STORE_KEY_CCM_PROCESSING);
        }
        await this.afterExecuteCommon(context);
    }
}
exports.SubmitSidechainCrossChainUpdateCommand = SubmitSidechainCrossChainUpdateCommand;
//# sourceMappingURL=submit_sidechain_cross_chain_update.js.map