/// <reference types="node" />
import { BaseCommand } from '../../base_command';
import { CommandExecuteContext, CommandVerifyContext, VerificationResult } from '../../../state_machine';
import { TokenMethod } from '../method';
import { TokenID } from '../types';
import { InternalMethod } from '../internal_method';
interface Params {
    tokenID: TokenID;
    amount: bigint;
    recipientAddress: Buffer;
    data: string;
}
export declare class TransferCommand extends BaseCommand {
    schema: {
        $id: string;
        title: string;
        type: string;
        required: string[];
        properties: {
            tokenID: {
                dataType: string;
                fieldNumber: number;
                minLength: number;
                maxLength: number;
            };
            amount: {
                dataType: string;
                fieldNumber: number;
            };
            recipientAddress: {
                dataType: string;
                fieldNumber: number;
                format: string;
            };
            data: {
                dataType: string;
                fieldNumber: number;
                minLength: number;
                maxLength: number;
            };
        };
    };
    private _method;
    private _internalMethod;
    init(args: {
        method: TokenMethod;
        internalMethod: InternalMethod;
    }): void;
    verify(context: CommandVerifyContext<Params>): Promise<VerificationResult>;
    execute(context: CommandExecuteContext<Params>): Promise<void>;
}
export {};
