/// <reference types="node" />
import { BaseEvent, EventQueuer } from '../../base_event';
import { TokenEventResult, TokenErrorEventResult } from '../constants';
export interface BurnEventData {
    address: Buffer;
    tokenID: Buffer;
    amount: bigint;
}
export declare const burnEventSchema: {
    $id: string;
    type: string;
    required: string[];
    properties: {
        address: {
            dataType: string;
            format: string;
            fieldNumber: number;
        };
        tokenID: {
            dataType: string;
            minLength: number;
            maxLength: number;
            fieldNumber: number;
        };
        amount: {
            dataType: string;
            fieldNumber: number;
        };
        result: {
            dataType: string;
            fieldNumber: number;
        };
    };
};
export declare class BurnEvent extends BaseEvent<BurnEventData & {
    result: TokenEventResult;
}> {
    schema: {
        $id: string;
        type: string;
        required: string[];
        properties: {
            address: {
                dataType: string;
                format: string;
                fieldNumber: number;
            };
            tokenID: {
                dataType: string;
                minLength: number;
                maxLength: number;
                fieldNumber: number;
            };
            amount: {
                dataType: string;
                fieldNumber: number;
            };
            result: {
                dataType: string;
                fieldNumber: number;
            };
        };
    };
    log(ctx: EventQueuer, data: BurnEventData): void;
    error(ctx: EventQueuer, data: BurnEventData, result: TokenErrorEventResult): void;
}
