"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CcmTransferEvent = exports.ccmTransferEventSchema = void 0;
const base_event_1 = require("../../base_event");
const constants_1 = require("../constants");
exports.ccmTransferEventSchema = {
    $id: '/token/events/ccmTransfer',
    type: 'object',
    required: [
        'senderAddress',
        'recipientAddress',
        'tokenID',
        'amount',
        'receivingChainID',
        'result',
    ],
    properties: {
        senderAddress: {
            dataType: 'bytes',
            format: 'lisk32',
            fieldNumber: 1,
        },
        recipientAddress: {
            dataType: 'bytes',
            format: 'lisk32',
            fieldNumber: 2,
        },
        tokenID: {
            dataType: 'bytes',
            minLength: constants_1.TOKEN_ID_LENGTH,
            maxLength: constants_1.TOKEN_ID_LENGTH,
            fieldNumber: 3,
        },
        amount: {
            dataType: 'uint64',
            fieldNumber: 4,
        },
        receivingChainID: {
            dataType: 'bytes',
            minLength: constants_1.CHAIN_ID_LENGTH,
            maxLength: constants_1.CHAIN_ID_LENGTH,
            fieldNumber: 5,
        },
        result: {
            dataType: 'uint32',
            fieldNumber: 6,
        },
    },
};
class CcmTransferEvent extends base_event_1.BaseEvent {
    constructor() {
        super(...arguments);
        this.schema = exports.ccmTransferEventSchema;
    }
    log(ctx, data) {
        this.add(ctx, { ...data, result: 0 }, [
            data.senderAddress,
            data.recipientAddress,
        ]);
    }
    error(ctx, data, result) {
        this.add(ctx, { ...data, result }, [data.senderAddress, data.recipientAddress], true);
    }
}
exports.CcmTransferEvent = CcmTransferEvent;
//# sourceMappingURL=ccm_transfer.js.map