/// <reference types="node" />
import { BaseEvent, EventQueuer } from '../../base_event';
import { TokenEventResult, TokenErrorEventResult } from '../constants';
export interface TransferCrossChainEventData {
    senderAddress: Buffer;
    tokenID: Buffer;
    amount: bigint;
    recipientAddress: Buffer;
    receivingChainID: Buffer;
}
export declare const transferCrossChainEventSchema: {
    $id: string;
    type: string;
    required: string[];
    properties: {
        senderAddress: {
            dataType: string;
            format: string;
            fieldNumber: number;
        };
        recipientAddress: {
            dataType: string;
            format: string;
            fieldNumber: number;
        };
        tokenID: {
            dataType: string;
            minLength: number;
            maxLength: number;
            fieldNumber: number;
        };
        amount: {
            dataType: string;
            fieldNumber: number;
        };
        receivingChainID: {
            dataType: string;
            minLength: number;
            maxLength: number;
            fieldNumber: number;
        };
        result: {
            dataType: string;
            fieldNumber: number;
        };
    };
};
export declare class TransferCrossChainEvent extends BaseEvent<TransferCrossChainEventData & {
    result: TokenEventResult;
}> {
    schema: {
        $id: string;
        type: string;
        required: string[];
        properties: {
            senderAddress: {
                dataType: string;
                format: string;
                fieldNumber: number;
            };
            recipientAddress: {
                dataType: string;
                format: string;
                fieldNumber: number;
            };
            tokenID: {
                dataType: string;
                minLength: number;
                maxLength: number;
                fieldNumber: number;
            };
            amount: {
                dataType: string;
                fieldNumber: number;
            };
            receivingChainID: {
                dataType: string;
                minLength: number;
                maxLength: number;
                fieldNumber: number;
            };
            result: {
                dataType: string;
                fieldNumber: number;
            };
        };
    };
    log(ctx: EventQueuer, data: TransferCrossChainEventData): void;
    error(ctx: EventQueuer, data: TransferCrossChainEventData, result: TokenErrorEventResult): void;
}
